import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { GetScheduleTimeFrameOptions, ScheduleTimeFrame, ListScheduleTimeFramesOptions, ListScheduleTimeFramesResponse, ScheduleTimeFrameUpdatedEnvelope } from './index.typings.js';
export { ActionEvent, Address, AddressHint, BaseEventMetadata, BusinessSchedule, Categories, ChangeContext, ChangeContextPayloadOneOf, ConsentPolicy, DayOfWeek, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GeoCoordinates, GetScheduleTimeFrameRequest, GetScheduleTimeFrameResponse, IdentificationData, IdentificationDataIdOneOf, ListScheduleTimeFramesRequest, Locale, MessageEnvelope, Multilingual, PlacementType, Properties, PropertiesChange, ResolutionMethod, RestoreInfo, SiteCloned, SiteCreated, SitePropertiesEvent, SitePropertiesNotification, SpecialHourPeriod, Status, SupportedLanguage, TimePeriod, Translation, WebhookIdentityType, ZonedDate } from './index.typings.js';

type ScheduleTimeFrameNonNullablePaths = `status`;
declare function getScheduleTimeFrame$1(httpClient: HttpClient): GetScheduleTimeFrameSignature;
interface GetScheduleTimeFrameSignature {
    /**
     * Retrieves a schedule time frame by schedule ID.
     * @param - [Schedule](https://dev.wix.com/docs/sdk/backend-modules/calendar/schedules/introduction)
     * ID for which to retrieve the schedule time frame.
     * @returns Retrieved schedule time frame.
     */
    (_id: string, options?: GetScheduleTimeFrameOptions): Promise<NonNullablePaths<ScheduleTimeFrame, ScheduleTimeFrameNonNullablePaths>>;
}
declare function listScheduleTimeFrames$1(httpClient: HttpClient): ListScheduleTimeFramesSignature;
interface ListScheduleTimeFramesSignature {
    /**
     * Retrieves a list of schedule time frames by schedule IDs.
     *
     *
     * Sorted by schedule ID in ascending order.
     * @param - IDs of the schedules for which to retrieve schedule time frames.
     *
     * Min: 1 schedule ID
     * Max: 100 schedule IDs
     */
    (ids: string[], options?: ListScheduleTimeFramesOptions): Promise<NonNullablePaths<ListScheduleTimeFramesResponse, {
        [P in ScheduleTimeFrameNonNullablePaths]: `scheduleTimeFrames.${number}.${P}`;
    }[ScheduleTimeFrameNonNullablePaths]>>;
}
declare const onScheduleTimeFrameUpdated$1: EventDefinition<ScheduleTimeFrameUpdatedEnvelope, "wix.calendar.v3.schedule_time_frame_updated">;

declare const getScheduleTimeFrame: MaybeContext<BuildRESTFunction<typeof getScheduleTimeFrame$1> & typeof getScheduleTimeFrame$1>;
declare const listScheduleTimeFrames: MaybeContext<BuildRESTFunction<typeof listScheduleTimeFrames$1> & typeof listScheduleTimeFrames$1>;
/**
 * Triggered when a schedule's time frame is updated, indicating a new first or
 * last event or a change in the recurrence period, such as an extension or
 * reduction.
 */
declare const onScheduleTimeFrameUpdated: BuildEventDefinition<typeof onScheduleTimeFrameUpdated$1>;

export { GetScheduleTimeFrameOptions, ListScheduleTimeFramesOptions, ListScheduleTimeFramesResponse, ScheduleTimeFrame, ScheduleTimeFrameUpdatedEnvelope, getScheduleTimeFrame, listScheduleTimeFrames, onScheduleTimeFrameUpdated };
